<?php
function npr_theme_init() {
	global $npr_theme_config, $theme_name, $theme_slug, $theme_version, $fields;
	
	$dir = get_template_directory();
	
	require_once($dir.'/admin/npr_default_config.php');
	require_once($dir.'/admin/npr_settings_panel.php');
	
	require_once($dir.'/admin/npr_post_types_init.php');
	
	require_once($dir.'/admin/npr_post_meta.php');
	
	require_once($dir.'/template_part/comments.php');
	
	//require_once($dir.'/shortcodes.php');
	
	if(is_admin()) {
		npr_save_defaults();
	}
	
}
add_action('after_setup_theme','npr_theme_init');

function npr_template_header() {
	global $npr_theme_config, $theme_name, $theme_slug, $theme_version, $fields;
	
	$js_dir = get_template_directory_uri().'/js/';
	//Wordpress-queued JQueryUI placed to wp_footer...
	wp_register_script('jquery-ui','http://code.jquery.com/ui/1.10.3/jquery-ui.js');
	
	wp_enqueue_script('jquery');
	wp_enqueue_script('jquery-ui');
	wp_enqueue_script('lightbox',$js_dir.'lightbox.js');
	wp_enqueue_script('template_shortcodes',$js_dir.'shortcodes.js');
	wp_enqueue_script('template_default',$js_dir.'scripts.js');
	
	
	/* GALLERY PAGE */
	$currentPage = get_page_template();
	if(strpos($currentPage,'page_gallery.php') > 0)
		wp_enqueue_script('page_gallery',$js_dir.'page_gallery.js');
	
	wp_enqueue_script('comment-reply');
	wp_localize_script('template_default','wp_npr_str',array(
		'comment_placeholder' => __('Comment','above_skyline_demo'),
		'comment_error' => __('Please write a comment','above_skyline_demo'),
		'comment_required' => __('Please fill all required field','above_skyline_demo'),
		'author_placeholder' => __('Name*','above_skyline_demo'),
		'email_placeholder' => __('E-mail*','above_skyline_demo'),
		'url_placeholder' => __('Website','above_skyline_demo'),
		'contact_name_placeholder' => __('Name','above_skyline_demo'),
		'contact_email_placeholder' => __('E-mail','above_skyline_demo'),
		'subject_placeholder' => __('Subject','above_skyline_demo'),
		'message_placeholder' => __('Message','above_skyline_demo'),
		'contact_name_required' => __('Name is required','above_skyline_demo'),
		'contact_email_required' => __('E-mail is required','above_skyline_demo'),
		'contact_subject_required' => __('Subject is required','above_skyline_demo'),
		'contact_message_required' => __('Message is required','above_skyline_demo'),
		'contact_captcha_not_match' => __('Numbers don\'t match','above_skyline_demo'),
		'contact_cpnres' => __('Result of ','above_skyline_demo'),
		'contact_wrongemail' => __('Invalid email','above_skyline_demo'),
		'contact_form_sent' => __('Message was sent. Thank you!','above_skyline_demo')
	));
	if(is_home()) {
		npr_init_home_scripts();
	}
	print '';
}

function npr_template_get_meta($meta = 'description') {
	global $post;
	$npr_post_meta = get_post_meta($post->ID,'npr_meta_'.$meta,true);
	($npr_post_meta != '') ? print $npr_post_meta :	bloginfo($meta);
}

function npr_template_get_title($titleo,$sep) {
	global $post,$category,$theme_slug;
	if(is_home()) {
		$npr_title = esc_html(stripslashes(npr_option('homepage_title')));
		if($npr_title == '')
			$title = get_bloginfo('name').' - '.get_bloginfo('description');
		else
			$title = $npr_title;
	} elseif(is_single($post->ID) || is_page($post->ID)) {
		if(get_post_meta($post->ID,'_npr_post_title',true) != '')
			$title = get_post_meta($post->ID,'_npr_post_title',true);
		else {
			$pattern = npr_option('post_title_pattern');
			$separator = (string) npr_option('post_title_separator');
			$title = npr_title_pattern($post->post_title,get_bloginfo('name'),$pattern,$separator);
		}
	} elseif(is_category()) {
		$categ = get_category(get_query_var('cat'));
		$pattern = npr_option('category_title_pattern');
		$separator = (string) npr_option('category_title_separator');
		$title = npr_title_pattern($categ->name,get_bloginfo('name'),$pattern,$separator);
	} else {
		$separator = (string) npr_option('post_title_separator');
		$title = str_ireplace($sep,$separator,$titleo) . ' ' . $separator . ' ' . get_bloginfo('name').' - '.get_bloginfo('description');
	}
	return $title;
}

add_filter( 'wp_title', 'npr_template_get_title', 10, 2 );

function npr_title_pattern($part1,$part2,$pattern,$separator) {
	switch($pattern) {
		case 1:
			$title = $part1.$separator.$part2;
			break;
		case 2:
			$title = $part2.$separator.$part1;
			break;
		default:
			$title = $part1;
			break;
	}
	return $title;
}

function npr_template_custom_meta() {
	global $post,$theme_slug;
	$meta = '';
	if(npr_option('enable_meta_desc') == 'true') {
		if(is_single($post->ID) || is_page($post->ID)) {
			$meta_description = get_post_meta($post->ID,'_npr_post_description',true);
		} elseif(is_category()) {
			$categ = get_category(get_query_var('cat'));
			$meta_description = $categ->category_description;
		}
		if($meta_description == '') $meta_description = npr_option('default_meta_description');
		if($meta_description != '')
			$meta .= '<meta name="description" value="'.esc_html(stripslashes($meta_description)).'" />'."\n";
	}
	if(npr_option('enable_meta_keywords') == 'true') {
		if(is_single($post->ID) || is_page($post->ID)) {
			$meta_keywords = get_post_meta($post->ID,'_npr_post_keywords',true);
		}
		if($meta_keywords == '') $meta_keywords = npr_option('default_meta_keywords');
		if($meta_keywords != '')
			$meta .= '<meta name="keywords" value="'.esc_html(stripslashes($meta_keywords)).'" />'."\n";
	}
	return $meta;
}

/* NAV */
function register_main_menus() {
	register_nav_menus(
		array(
			'primary-menu' => 'Primary Menu',
			'footer-menu' => 'Footer Menu'
		)
	);
}
add_action( 'init', 'register_main_menus' );



/* WIDGETS */
function npr_register_widget() {
	register_sidebar( array(
		'name' => 'Sidebar',
		'id' => 'sidebar',
		'before_widget' => '<div class="sidebar-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
	register_sidebar( array(
		'name' => 'Footer Area #1',
		'id' => 'footer_1',
		'before_widget' => '<div class="sidebar-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
	register_sidebar( array(
		'name' => 'Footer Area #2',
		'id' => 'footer_2',
		'before_widget' => '<div class="sidebar-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
	register_sidebar( array(
		'name' => 'Footer Area #3',
		'id' => 'footer_3',
		'before_widget' => '<div class="sidebar-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
}
add_action('widgets_init','npr_register_widget');


function npr_searchbox_is_active() {
	return true;
}

function npr_header_ok($header=true) {
	global $post;
	$pref = ($header === true ? 'header' : 'footer');
	$ret = array('show' => true,'html' => '');
	$meta = get_post_meta($post->ID,'npr_'.$pref.'_on',true); if($meta == '') $meta = 1;
	$admin = current_user_can('edit_post', $post->ID);
	if($meta == 0 && $admin === true) {
		$ret['html'] = ' display:none; ';
	} elseif($meta == 0) {
		$ret['show'] = false;
	}
	return $ret;
}

function npr_option($op,$default='') {
	global $theme_slug;
	return get_option($theme_slug.'_'.$op,$default);
}

function npr_post_info_box($post,$options) {
	global $post, $authordata, $theme_slug;
	$ex = explode('|',$options);
	if(strlen($options) > 1)
	?>
	<div class="post-info">
	<?php
	if(in_array('user',$ex)) {
		?>
		<span class="post-info-box"><i class="fa fa-user icon"></i> <?php the_author_posts_link(); ?></span>
		<?php
	}
	if(in_array('date',$ex)) {
		?>
		<span class="post-info-box"><i class="fa fa-calendar icon"></i> <?php the_date(); ?></span>
		<?php
	}
	if(in_array('category',$ex)) {
		?>
		<span class="post-info-box"><i class="fa fa-list icon"></i> <?php the_category(', ') ?></span>
		<?php
	}
	if(in_array('comments',$ex)) {
		?>
		<span class="post-info-box"><i class="fa fa-comments icon"></i> <a href="<?php comments_link(); ?>"><?php comments_number(__('0','above_skyline_demo'),__('1','above_skyline_demo'),__('%','above_skyline_demo')); ?></a></span>
		<?php
		/*  <span class="topinfo_extra"> Comment</span> <span class="topinfo_extra"> Comments</span> */
	}
	if(strlen($options) > 1)
	?>
	</div>
	<?php
}


function npr_init_home_scripts() {
	$js_dir = get_template_directory_uri().'/js/';
	
	wp_enqueue_script('npr_home_scroll',$js_dir.'bxslider/jquery.bxslider.js');
	wp_enqueue_script('npr_home_all',$js_dir.'functions_home.js');
	
	wp_enqueue_style('npr_home_scroll_css',$js_dir.'bxslider/jquery.bxslider.css');
}

class nicepress_walker_nav_menu extends Walker_Nav_Menu {
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

		$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
		$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

		$output .= $indent . '<li' . $id . $value . $class_names .'>';

		$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
		$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
		$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
		$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>';
		$item_output .= $args->link_before . ($depth > 0 ? $args->sub_link_before : '') . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters('walker_nav_menu_start_el',$item_output,$item,$depth,$args);
	}
}

function npr_newline($str) {
	$arr = explode("\n",$str);
	$out = '';
	for($i = 0;$i<count($arr);$i++) {
		if(strlen(trim($arr[$i]))>0)
			$out .= '<p>'.trim($arr[$i]).'</p>';
	}
    return $out;
}


function npr_sidebar_position() {
	$pos = npr_option('sidebar_position');
	switch($pos) {
		case "1":
			$class = 'fullwidth';
		break;
		case "2":
			$class = 'sidebar_left';
			break;
		case "3":
			$class = 'sidebar_right';
			break;
		default:
			$class = 'sidebar_right';
			break;
	}
	return $class;
}


/*  */
function npr_custom_styles() {
	$style_opts = npr_option('styles');
	$primaryFontFile = '//fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800';
	$secondaryFontFile = '//fonts.googleapis.com/css?family=Yanone+Kaffeesatz:400,200,300,700';
	if(is_array($style_opts)) {
		$pf = explode('|',$style_opts['body_font']);
		if($pf[2] != $primaryFontFile) $customFont = true;
		$primaryFont = $pf[1];
		$primaryFontFile = $pf[2];
		$sf = explode('|',$style_opts['header_font']);
		if($sf[2] != $secondaryFontFile) $customFont = true;
		$secondaryFont = $sf[1];
		$secondaryFontFile = $sf[2];
		if($style_opts['subtheme'] == '') {
		?>
		<style type="text/css">
			
			/* HEADER */
			#header_container { background-color: <?php print esc_html($style_opts['header_color']);?>; }
			#main_header { background-color: <?php print esc_html($style_opts['header_color']);?>; }
			
			#top_searchbox { border: 1px solid <?php print esc_html($style_opts['header_shadow']);?>; }
			
			/* MAIN NAV */
			#main_nav ul > li > a:hover,
			#main_nav ul > li.current-menu-item > a,
			#main_nav ul > li.current-page-parent > a {
				color: <?php print esc_html($style_opts['header_shadow']);?>;
			}
			
			/* sidebar */
			.sidebar-widget { border-bottom: 4px solid <?php print esc_html($style_opts['header_color']);?>; }
			.sidebar-widget ul li:hover a .icon { color: <?php print esc_html($style_opts['header_color']);?>; }
			
			
			/* HOME */
			.npr_home_tabs li.npr_tab_active, .npr_home_tabs li:hover {
				background-color: <?php print esc_html($style_opts['header_color']);?>;
				-webkit-box-shadow:  0px 0px 20px 0px rgba(0, 0, 0, .1),  inset 0px 0px 20px 0px <?php print esc_html($style_opts['header_shadow']);?>;
				box-shadow:  0px 0px 20px 0px rgba(0, 0, 0, .1), inset 0px 0px 20px 0px <?php print esc_html($style_opts['header_shadow']);?>;
			}
			.npr_home_tabs { border-bottom: 4px solid <?php print esc_html($style_opts['header_color']);?>; }
			
			/* FOOTER NAV */
			#footer_nav ul > li > a:hover,
			#footer_nav ul > li.current-menu-item > a,
			#footer_nav ul > li.current-page-parent > a {
				color: <?php print esc_html($style_opts['header_shadow']);?>;
			}
			#footer_nav ul > li > ul.sub-menu > li.current-page-parent > a .fa-chevron-right { color: <?php print esc_html($style_opts['header_shadow']);?>; }
			
			/* MISC */
			.header_shadow {
				-webkit-box-shadow:  0px 0px 50px 0px rgba(0, 0, 0, .1),  inset 0px 0px 50px 0px <?php print esc_html($style_opts['header_shadow']);?>;
				box-shadow:  0px 0px 50px 0px rgba(0, 0, 0, .1), inset 0px 0px 50px 0px <?php print esc_html($style_opts['header_shadow']);?>;
			}
			
			/* MOBILE */
			
			#mobile_header a.mobile_menu { color: <?php print esc_html($style_opts['header_shadow']);?>; }
				
			#mobile_header_nav_open ul > li > a:hover,
			#mobile_header_nav_open ul > li.current-menu-item > a,
			#mobile_header_nav_open ul > li.current-page-parent > a {
				color: <?php print esc_html($style_opts['header_shadow']);?>;
			}
				
			#mobile_header_nav_open ul > li > a:hover .fa-chevron-right,
			#mobile_header_nav_open ul > li.current-menu-item > a .fa-chevron-right,
			#mobile_header_nav_open ul > li.current-page-parent > a .fa-chevron-right { color: <?php print esc_html($style_opts['header_shadow']);?>; }
				
			#mobile_footer_nav_open ul > li > a:hover,
			#mobile_footer_nav_open ul > li.current-menu-item > a,
			#mobile_footer_nav_open ul > li.current-page-parent > a {
				color: <?php print esc_html($style_opts['header_shadow']);?>;
			}
				
			#mobile_footer_nav_open ul > li > a:hover .fa-chevron-right,
			#mobile_footer_nav_open ul > li.current-menu-item > a .fa-chevron-right,
			#mobile_footer_nav_open ul > li.current-page-parent > a .fa-chevron-right { color: <?php print esc_html($style_opts['header_shadow']);?>; }
			
			.bx-wrapper { background: <?php print esc_html($style_opts['slider_bg']);?>; }
			
			
			
		</style>
		<?php
		}
		if($style_opts['subtheme'] != '') {?>
			<link rel="stylesheet" href="<?php print esc_html($style_opts['subtheme']);?>" type="text/css" id="subtheme" />
		<?php }
	}
	if($customFont) { ?>
	<style type="text/css">
		body { font-family: <?php print $primaryFont;?>; }
		a { font-family: <?php print $primaryFont;?>; }
		textarea,input,select { font-family: <?php print $primaryFont;?>; }
			
		h1,h2,h3,h4,h5,h6 { font-family: <?php print $secondaryFont;?>; }
		h1.title, #reply-title { font-family: <?php print $secondaryFont;?>; }
		.content-title h1, .content-title h1 a { font-family: <?php print $secondaryFont;?>; }
		.gallery-list li h2 { font-family: <?php print $secondaryFont;?>; }
		#top_info { font-family: <?php print $secondaryFont;?>; }
		.hmb_content h3 a { font-family: <?php print $secondaryFont;?>; }
		#npr_home_slider h1 a { font-family: <?php print $secondaryFont;?>; }
		.footer_widget .sidebar-widget h2 { font-family: <?php print $secondaryFont;?>; }
	</style>
	<?php } ?>
	<link rel="stylesheet" type="text/css" href="<?php print $primaryFontFile;?>" />
	<link rel="stylesheet" type="text/css" href="<?php print $secondaryFontFile;?>" />
	<?php
}

function npr_paste_theme_slug() {
	global $wp_customize, $theme_slug;
    // If $wp_customize is set, return
    if (isset($wp_customize)) {
        ?>
		<script type="text/javascript">
			var theme_slug = '<?php print $theme_slug;?>';
		</script>
		<?php
    }
}
add_action('wp_head','npr_paste_theme_slug');


add_action('customize_register','npr_init_customize');
function npr_init_customize($customize_obj) {
	global $theme_slug;
	
	$customize_obj->remove_section('title_tagline');
	$customize_obj->remove_section('background_image');
		
	$getfonts = npr_fonts_list();
	if(is_array($getfonts)) {
		foreach($getfonts AS $k => $d) {
			$fonts[$k . '|' . $d['css'] . '|' . $d['url']] = $k;
		}
	}
	
	/* COLOR SETTINGS */
	
	$customize_obj->add_setting($theme_slug . '_styles[header_color]', array(
		'default'		=> '#E1800B',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage'
	));

	$customize_obj->add_control( new WP_Customize_Color_Control($customize_obj, $theme_slug . '_styles[header_color]', array(
		'label'		=> __('Header Color','above_skyline_demo'),
		'section'	=> 'colors',
		'settings'	=> $theme_slug . '_styles[header_color]',
	)));
	
	$customize_obj->add_setting($theme_slug . '_styles[header_shadow]', array(
		'default'		=> '#F36603',
		'description'	=> 'Also used as accent color',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage'
	));

	$customize_obj->add_control( new WP_Customize_Color_Control($customize_obj, $theme_slug . '_styles[header_shadow]', array(
		'label'		=> __('Header Shadow','above_skyline_demo'),
		'section'	=> 'colors',
		'settings'	=> $theme_slug . '_styles[header_shadow]',
	)));
	
	$customize_obj->add_setting($theme_slug . '_styles[slider_bg]', array(
		'default'		=> '#dddddd',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage'
	));

	$customize_obj->add_control( new WP_Customize_Color_Control($customize_obj, $theme_slug . '_styles[slider_bg]', array(
		'label'		=> __('Slider Background','above_skyline_demo'),
		'section'	=> 'colors',
		'settings'	=> $theme_slug . '_styles[slider_bg]',
	)));
	
	/* FONT SETTINGS */
	$customize_obj->add_section('npr_fonts',array(
		'title'		=> __('Fonts','above_skyline_demo'),
		'priority'	=> 50
	));
	
	$customize_obj->add_setting($theme_slug . '_styles[header_font]', array(
		'default'		=> "Yanone Kaffeesatz|'Yanone Kaffeesatz', sans-serif|//fonts.googleapis.com/css?family=Yanone+Kaffeesatz:400,200,300,700",
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage'
	));

	$customize_obj->add_control($theme_slug . '_styles[header_font]', array(
		'label'		=> __('Header Font','above_skyline_demo'),
		'section'	=> 'npr_fonts',
		'settings'	=> $theme_slug . '_styles[header_font]',
		'type'		=> 'select',
		'choices'	=> $fonts
	));

	$customize_obj->add_setting($theme_slug . '_styles[body_font]', array(
		'default'		=> "Open Sans|'Open Sans', sans-serif|//fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800",
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage'
	));

	$customize_obj->add_control($theme_slug . '_styles[body_font]', array(
		'label'		=> __('Body Font','above_skyline_demo'),
		'section'	=> 'npr_fonts',
		'settings'	=> $theme_slug . '_styles[body_font]',
		'type'		=> 'select',
		'choices'	=> $fonts
	));
	
	/* SHEME SETTINGS */

	$customize_obj->add_section('npr_shemes', array(
		'title'       => __('Schemes','above_skyline_demo'),
		'priority'    => 60,
		'description' => 'Please select &quot;Default&quot; to use your custom color settings'
	));
	
	$customize_obj->add_setting($theme_slug . '_styles[subtheme]', array(
		'default'		=> '',
		'type'			=> 'option',
		'capability'	=> 'edit_theme_options',
		'transport'		=> 'postMessage'
	));

	$customize_obj->add_control($theme_slug . '_styles[subtheme]',array(
		'label'		=> __('Color Schemes','above_skyline_demo'),
		'section'	=> 'npr_shemes',
		'settings'	=> $theme_slug . '_styles[subtheme]',
		'type'		=> 'select',
		'choices'	=> array(
			''   => __('Default','above_skyline_demo'),
			get_template_directory_uri() . '/css/style_blue.css'   => __('Blue','above_skyline_demo'),
			get_template_directory_uri() . '/css/style_green.css'  => __('Green','above_skyline_demo'),
			get_template_directory_uri() . '/css/style_red.css'    => __('Red','above_skyline_demo'),
			get_template_directory_uri() . '/css/style_gray.css'   => __('Gray','above_skyline_demo'),
			get_template_directory_uri() . '/css/style_lblue.css' => __('Light blue','above_skyline_demo'),
		)
	));
		
		
		
}


add_action('customize_preview_init','npr_preview_init');
function npr_preview_init() {
	wp_enqueue_script('theme_customize', get_template_directory_uri() . '/admin/js/theme_customize.js', array('customize-preview'), false, true);
}


function npr_fonts_list() {
	$fonts = array(
		'Open Sans' => array(
			'url' => '//fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800',
			'css' => "'Open Sans', sans-serif"
		),
		'Droid Sans' => array(
			'url' => '//fonts.googleapis.com/css?family=Droid+Sans:400,700',
			'css' => "'Droid Sans', sans-serif"
		),
		'PT Sans' => array(
			'url' => '//fonts.googleapis.com/css?family=PT+Sans:400,700,400italic,700italic',
			'css' => "'PT Sans', sans-serif"
		),
		'PT Sans Narrow' => array(
			'url' => '//fonts.googleapis.com/css?family=PT+Sans+Narrow:400,700',
			'css' => "'PT Sans Narrow', sans-serif"
		),
		'Oswald' => array(
			'url' => '//fonts.googleapis.com/css?family=Oswald:400,300,700',
			'css' => "'Oswald', sans-serif"
		),
		'Lato' => array(
			'url' => '//fonts.googleapis.com/css?family=Lato:100,300,400,700,900,100italic,300italic,400italic,700italic,900italic',
			'css' => "'Lato', sans-serif"
		),
		'Lato' => array(
			'url' => '//fonts.googleapis.com/css?family=Lato:100,300,400,700,900,100italic,300italic,400italic,700italic,900italic',
			'css' => "'Lato', sans-serif"
		),
		'Yanone Kaffeesatz' => array(
			'url' => '//fonts.googleapis.com/css?family=Yanone+Kaffeesatz:400,200,300,700',
			'css' => "'Yanone Kaffeesatz', sans-serif"
		),
		'Roboto' => array(
			'url' => '//fonts.googleapis.com/css?family=Roboto:400,100,100italic,300,300italic,400italic,500,500italic,700,900,700italic,900italic',
			'css' => "'Roboto', sans-serif"
		),
		'Nunito' => array(
			'url' => '//fonts.googleapis.com/css?family=Nunito:400,300,700',
			'css' => "'Nunito', sans-serif"
		),
		'Raleway' => array(
			'url' => '//fonts.googleapis.com/css?family=Raleway:400,100,200,300,500,600,700',
			'css' => "'Raleway', sans-serif"
		),
		'Dosis' => array(
			'url' => '//fonts.googleapis.com/css?family=Dosis:200,300,400,500,600,700',
			'css' => "'Dosis', sans-serif"
		),
		'Droid Serif' => array(
			'url' => '//fonts.googleapis.com/css?family=Droid+Serif:400,700,400italic,700italic',
			'css' => "'Droid Serif', serif"
		),
		'PT Serif' => array(
			'url' => '//fonts.googleapis.com/css?family=PT+Serif:400,700,400italic,700italic',
			'css' => "'PT Serif', serif"
		),
		'Merriweather' => array(
			'url' => '//fonts.googleapis.com/css?family=Merriweather:400,300,300italic,400italic,700,700italic',
			'css' => "'Merriweather', serif"
		),
		'Vollkorn' => array(
			'url' => '//fonts.googleapis.com/css?family=Vollkorn:400italic,700italic,400,700',
			'css' => "'Vollkorn', serif"
		),
		'Kreon' => array(
			'url' => '//fonts.googleapis.com/css?family=Kreon:300,400,700',
			'css' => "'Kreon', serif"
		),
		'Josefin Slab' => array(
			'url' => '//fonts.googleapis.com/css?family=Josefin+Slab:300,400,600,700',
			'css' => "'Josefin Slab', serif"
		),
		'Bree Serif' => array(
			'url' => '//fonts.googleapis.com/css?family=Bree+Serif',
			'css' => "'Bree Serif', serif"
		),
		'Sanchez' => array(
			'url' => '//fonts.googleapis.com/css?family=Sanchez:400italic,400',
			'css' => "'Sanchez', serif"
		),
		'Noticia Text' => array(
			'url' => '//fonts.googleapis.com/css?family=Noticia+Text:400,400italic,700,700italic',
			'css' => "'Noticia Text', serif"
		),
		'Judson' => array(
			'url' => '//fonts.googleapis.com/css?family=Judson:400,700,400italic',
			'css' => "'Judson', serif"
		),
		'Lobster' => array(
			'url' => '//fonts.googleapis.com/css?family=Lobster',
			'css' => "'Lobster', cursive"
		),
		'Changa One' => array(
			'url' => '//fonts.googleapis.com/css?family=Changa+One',
			'css' => "'Changa One', cursive"
		),
		'Comfortaa' => array(
			'url' => '//fonts.googleapis.com/css?family=Comfortaa',
			'css' => "'Comfortaa', cursive"
		),
		'Luckiest Guy' => array(
			'url' => '//fonts.googleapis.com/css?family=Luckiest+Guy',
			'css' => "'Luckiest Guy', cursive"
		),
		'Happy Monkey' => array(
			'url' => '//fonts.googleapis.com/css?family=Happy+Monkey',
			'css' => "'Happy Monkey', cursive"
		),
		'Pirata One' => array(
			'url' => '//fonts.googleapis.com/css?family=Pirata+One',
			'css' => "'Pirata One', cursive"
		),
		'Coming Soon' => array(
			'url' => '//fonts.googleapis.com/css?family=Coming+Soon',
			'css' => "'Coming Soon', cursive"
		),
		'Calligraffitti' => array(
			'url' => '//fonts.googleapis.com/css?family=Calligraffitti',
			'css' => "'Calligraffitti', cursive"
		),
		'Satisfy' => array(
			'url' => '//fonts.googleapis.com/css?family=Satisfy',
			'css' => "'Satisfy', cursive"
		),
		'Permanent Marker' => array(
			'url' => '//fonts.googleapis.com/css?family=Permanent+Marker',
			'css' => "'Permanent Marker', cursive"
		),
		'Indie Flower' => array(
			'url' => '//fonts.googleapis.com/css?family=Indie+Flower',
			'css' => "'Indie Flower', cursive"
		),
	);
	
	return $fonts;
	
}


/* DEMO CONTENT */
function nprGetTabsDemo() {
	$demo = array();
	$demo['tabs'] = '';
	$demo['content'] = '';
	
	$i = 0;
	$inits = array('First','Second','Third');
	foreach($inits AS $num) {
		$demo['tabs'] .= '<li'.($i == 0 ? ' class="npr_tab_active"' : '').'><a href="#" rel="'.$i.'">'.$num.' tab</a></li>';
		$demo['content'] .= '
		<div class="content npr_home_tab_content'.($i == 0 ? ' npr_tab_active' : '').'" id="npr_tab_content_'.$i.'">
			<h2>'.$num.' tab</h2>
			<p><strong>Open WordPress admin to add your own content</strong></p>
			<p>Praesent et pharetra dui, et ornare lectus. Sed et quam eu nibh ornare fringilla nec in eros. Mauris feugiat rhoncus orci, et posuere ipsum varius non. Vestibulum posuere egestas velit eget tristique. Donec sed malesuada quam. Praesent sodales in nisi sed vulputate. Fusce suscipit risus eros, eget dictum orci rutrum in. Fusce eget est in erat volutpat dignissim in at risus. Etiam facilisis tempus tincidunt. Vivamus fringilla, turpis vitae laoreet hendrerit, elit justo sagittis arcu, volutpat aliquet elit metus eu lorem. Nam tempor elementum purus, vitae volutpat metus hendrerit eget.</p>
	
			<p>Pellentesque a enim a leo finibus laoreet. Aenean augue ex, fringilla eget eros vitae, venenatis ornare mi. Etiam semper arcu lacus, at varius urna luctus quis. Nullam tristique massa et purus aliquam, a cursus lacus faucibus. Sed efficitur suscipit condimentum. Sed a bibendum est. Cras viverra risus ac condimentum ultricies. In magna ante, dapibus cursus dignissim viverra, vehicula id justo.</p>
		</div>';
		$i++;
	}
	
	return $demo;
}

function nprGetMiniboxDemo() {
	$demo = array();
	$demo['minibox'] = '';
	
	$i = 0;
	$inits = array('First','Second','Third','Fourth');
	$icons = array('fa-check','fa-mobile','fa-code','fa-comments-o');
	foreach($inits AS $num) {
		$demo['minibox'] .= '
		<div class="npr_home_minibox w25">
			<div class="nhm_icon">
				<div class="icon_p"><i class="icon fa fa-5x '.$icons[$i].'"></i></div>
			</div>
			<div class="hmb_content">
				<h3><a href="#">'.$num.' minibox</a></h3>
				<p><strong>Open WordPress admin to add your own content</strong> Aliquam lobortis mi in tincidunt vestibulum. Morbi mi dolor, dapibus vitae risus commodo, porta porta neque. Donec facilisis lorem non egestas hendrerit. Sed in imperdiet lacus, et imperdiet libero.</p>
			</div>
		</div>';
		$i++;
	}
	
	return $demo;
}


function nprGetSliderDemo() {
	$demo = array();
	$demo['slides'] = '';
	
	$infos = array(
				   0 => array('Above Skyline','Responsive Wordpress Theme','slide4.jpg'),
				   1 => array('Fully Customizable','Lorem ipsum dolor sit amet','slide3.jpg'),
				   2 => array('Retina Display Compatible','Lorem ipsum dolor sit amet','slide2.jpg'),
				   3 => array('Something Wonderful','Lorem ipsum dolor sit amet','slide1.jpg'),
				   );
	
	foreach($infos AS $num) {
		$demo['slides'] .= '<li>
			<h1><a href="#">'.$num[0].'</a></h1>
			<div class="slider_content">
				'.$num[1].'
			</div>
			<div class="slider_image"><img src="'.get_template_directory_uri() . '/images/' . $num[2] . '" alt="<?php print $post_title;?>" /></div>
		</li>';
	}
	
	return $demo;
	
}

if ( ! isset( $content_width ) ) $content_width = 1000;

add_theme_support('post-thumbnails');
add_theme_support( 'automatic-feed-links' );
add_post_type_support('page', 'excerpt');
remove_filter('term_description','wpautop');


?>